#!/bin/bash

#   install_backup.sh - configure a backup script
#
#   DISS - Debian Install Server Scripts
#   A set of scripts to automate installation of Servers on Debian
#   (c) 2009 Emmanuel Revah - manu-at-manurevah.com
#
#   This file is part of DISS.
#
#   DISS is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   DISS is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with DISS.  If not, see <http://www.gnu.org/licenses/>.

clear
source /etc/diss/diss.conf
source ${SCRIPTS}/functions.sh

THISSCRIPT=install_backup.sh
THISSTATE=${BACKUPSTATE}
installStatus

# test if install_base has been done, if not show a message
DEPENDSTATE=${BASESTATE}
DEPENDSON="install_base"
dependsOn

clear
echo "

########################################################

This script will create a backup script for your system.
for this you can use a combination of:

- local backup: will be used in all cases (or not?)
- ftp : requires a remote ftp server account

OPTIONAL: If you need to delete your previous backup from
the FTP server you can create a file containing the
correct commands for that in:
 \"/etc/diss/ftp_pre_backup_commands\"

This file should contain the ftp commands you would
use such as:

cd backup-folder
rm backup*
quit

#########################################################
"

echo -n "We'll assume that we want to save every database

We shall also save the following folders : \"/etc /home/vmail /home/www /var/log /usr/local/sbin /var/cache/awstats\"
however if you need to modify this please do so carefully by entering ALL folders that need to be backed up
use space separated values. You may add or remove folders later on from /etc/diss/diss.conf
(TO USE THE DEFAULT SETTINGS JUST PRESS ENTER)
folders to be saved : "
read BACKUPDIRS
: ${BACKUPDIRS:="/etc /home/vmail /home/www /var/log /usr/local/sbin /var/cache/awstats"}

getInpute "FTP server we should use:" domain
BACKUPFTPHOST="${ANSWER}"
getInpute "FTP username:" user
BACKUPFTPUSER="${ANSWER}"
getInpute "FTP password:"
BACKUPFTPPASS="${ANSWER}"
getInpute "FTP backup directory:" dir
BACKUPFTPDIR="${ANSWER}"

echo "
Before sending the backup to the FTP server we should encrypt it.
We'll make one image out of the daily backup, you should not
consider data flowing over FTP as safe, and you might not
trust the admin of the FTP server.
For these reasons choose a password to encrypt the daily backup"
getInpute "Encryption password: " pw
BACKUPKEY="${ANSWER}"

echo -n "
We shall create \"/home/backup\" and store the backup there,
if you want to use a different folder you may say so here,
else just press enter: "
read BACKUPROOT
: ${BACKUPROOT:="/home/backup"}

echo -n "h
ow many days worth of backup do we keep (default 5): "
read BACKUPDAYS
: ${BACKUPDAYS:="5"}

# confirm stuff
echo "

the backup goes like this:

Folders to be backed up: ${BACKUPDIRS}
FTP server to use: ${NCFTPBOOKMARK}
FTP username: ${BACKUPFTPUSER}
FTP password: ${BACKUPFTPPASS}
FTP backup folder: ${BACKUPFTPDIR}
Local backupfolder: ${BACKUPROOT}
Conserve backups (days): ${BACKUPDAYS}
Backup key: ${BACKUPKEY}

Please verify the above information"
confirmORdie

# create backup dir
mkdir ${BACKUPROOT}
chmod 700 ${BACKUPROOT}
chown root:root ${BACKUPROOT}

# actually start doing stuff
sed -i "s#BACKUPDIRS=#BACKUPDIRS=\"${BACKUPDIRS}\"#" /etc/diss/diss.conf
sed -i "s/BACKUPFTPHOST=/BACKUPFTPHOST=\"${BACKUPFTPHOST}\"/" /etc/diss/diss.conf
sed -i "s/BACKUPFTPUSER=/BACKUPFTPUSER=\"${BACKUPFTPUSER}\"/" /etc/diss/diss.conf
sed -i "s/BACKUPFTPPASS=/BACKUPFTPPASS=\"${BACKUPFTPPASS}\"/" /etc/diss/diss.conf
sed -i "s#BACKUPFTPDIR=#BACKUPFTPDIR=\"${BACKUPFTPDIR}\"#" /etc/diss/diss.conf
sed -i "s/BACKUPDAYS=/BACKUPDAYS=\"${BACKUPDAYS}\"/" /etc/diss/diss.conf
sed -i "s/BACKUPKEY=/BACKUPKEY=\"${BACKUPKEY}\"/" /etc/diss/diss.conf
sed -i "s#BACKUPROOT=#BACKUPROOT=\"${BACKUPROOT}\"#" /etc/diss/diss.conf
echo "0 4 * * * root /usr/local/sbin/backup_diss.sh" >> /etc/crontab
ln -s /usr/local/${SOFTNAME}/sbin/backup_diss.sh /usr/local/sbin/

# mark as done
sed -i "s/BACKUPSTATE=\"not installed\"/BACKUPSTATE=\"done\"/" /etc/diss/diss.conf

echo "Backup configured.
It will run every morning at 4AM, to change that edit
the file /etc/crontab.
These folders will be backed up : ${BACKUPDIRS}

Edit /etc/diss/diss.conf at the line 'BACKUPDIRS' to add or remove directories.

Press enter to return to main menu"
read
exit
