/*
Mailboy - A Php/MySQL application that offers a web based interface
to administer an email server. It can be used by the server administrator
as well as the email users.
(c) 2009 Emmanuel Revah - manu-at-manurevah.com
http://manurevah.com/blah/en/pages/mailboy

This file is part of Mailboy.

Mailboy is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Mailboy is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Mailboy.  If not, see <http://www.gnu.org/licenses/>.
*/

CREATE TABLE IF NOT EXISTS `virtual_domains` (
	id INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
	name VARCHAR(64) NOT NULL,
	default_policy INT(11) NOT NULL,
	default_quota_kb INT(11) NOT NULL DEFAULT '0',
	PRIMARY KEY (`id`),
	UNIQUE KEY `name` (`name`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `virtual_users` (
	id INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
	domain_id INT(11) UNSIGNED NOT NULL,
	user VARCHAR(64) NOT NULL,
	password VARCHAR(32) NOT NULL,
	quota_kb INT(11) NOT NULL DEFAULT '0',
	quota_messages INT(11) NOT NULL DEFAULT '0',
	policy_id INT(11) UNSIGNED NOT NULL,
	admin TINYINT(1)  UNSIGNED NOT NULL DEFAULT '0',
	PRIMARY KEY (`id`),
	UNIQUE key `account` (`domain_id`,`user`),
	/* FOREIGN KEY (`domain_id`) REFERENCES `virtual_domains`(`id`) ON DELETE RESTRICT */
	FOREIGN KEY (`domain_id`) REFERENCES `virtual_domains`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `virtual_aliases` (
	id INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
	domain_id INT(11) UNSIGNED NOT NULL,
	source VARCHAR(64) NOT NULL,
	destination VARCHAR(127) NOT NULL,
	PRIMARY KEY (`id`),
	UNIQUE KEY `alias` (`domain_id`,`source`,`destination`),
	FOREIGN KEY (`domain_id`) REFERENCES `virtual_domains`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `domain_admin_assoc` (
    `user_id` INT(11) UNSIGNED NOT NULL,
    `domain_id` INT(11) UNSIGNED NOT NULL,
    PRIMARY KEY (`user_id`, `domain_id`),
    FOREIGN KEY (`user_id`) REFERENCES `virtual_users`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`domain_id`) REFERENCES `virtual_domains`(`id`) ON DELETE CASCADE
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `relay_domains` (
	`id` INT(11) NOT NULL AUTO_INCREMENT,
	`domain` VARCHAR(50) NOT NULL,
	PRIMARY KEY  (`id`),
	UNIQUE KEY `domain` (`domain`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;
INSERT INTO `relay_domains` (`id`, `domain`) VALUES
(1, '$mydestination');

/* POLICY */
CREATE TABLE IF NOT EXISTS `policy` (
	`id` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
	`policy_name` VARCHAR(255) DEFAULT NULL,
	`virus_lover` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`spam_lover` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`banned_files_lover` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`bad_header_lover` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`bypass_virus_checks` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`bypass_spam_checks` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`bypass_banned_checks` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`bypass_header_checks` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`spam_modifies_subj` ENUM('Y', 'N') DEFAULT 'N' NOT NULL,
	`spam_quarantine_to` VARCHAR(128) DEFAULT NULL,
	`spam_tag_level` FLOAT DEFAULT '999',
	`spam_tag2_level` FLOAT DEFAULT '999',
	`spam_kill_level` FLOAT DEFAULT '999',
	PRIMARY KEY (`id`),
	UNIQUE KEY `policy_name` (`policy_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

/* VIEWS */
CREATE VIEW view_users AS
SELECT virtual_users.id AS uid, user, CONCAT(user, '@', name) AS email, password,
quota_kb, quota_messages,
name AS domain, virtual_domains.id AS domain_id, policy_name, policy_id, admin,
GROUP_CONCAT(DISTINCT domain_admin_assoc.domain_id) AS admin_of_ids,
GROUP_CONCAT((SELECT virtual_domains.name FROM virtual_domains WHERE domain_admin_assoc.domain_id = virtual_domains.id)) AS admin_of_names
FROM virtual_users
LEFT JOIN virtual_domains ON (virtual_users.domain_id = virtual_domains.id)
LEFT JOIN policy ON (virtual_users.policy_id = policy.id)
LEFT JOIN domain_admin_assoc ON (virtual_users.id = domain_admin_assoc.user_id)
GROUP BY virtual_users.id;

CREATE VIEW view_aliases AS
SELECT virtual_aliases.id, domain_id, source, name, CONCAT(source, '@', name) AS email, destination
FROM virtual_aliases
LEFT JOIN virtual_domains ON (virtual_aliases.domain_id = virtual_domains.id);

CREATE VIEW view_domains AS
SELECT virtual_domains.id, virtual_domains.name, virtual_domains.default_policy, policy_name, policy.id AS policy_id,
virtual_domains.default_quota_kb AS default_quota,
(SELECT count(virtual_users.id) FROM virtual_users WHERE virtual_users.domain_id = virtual_domains.id) AS accounts,
(SELECT count(virtual_aliases.id) FROM virtual_aliases WHERE virtual_aliases.domain_id = virtual_domains.id) AS aliases
FROM virtual_domains
LEFT JOIN policy ON (virtual_domains.default_policy = policy.id);

CREATE VIEW view_users_policies AS
SELECT uid, email, virus_lover, spam_lover, banned_files_lover, bad_header_lover, bypass_virus_checks, bypass_spam_checks, bypass_banned_checks,
bypass_header_checks, spam_modifies_subj, spam_quarantine_to, spam_tag_level, spam_tag2_level, spam_kill_level
FROM view_users, policy
WHERE (view_users.policy_id = policy.id);
